Learn R Programming

Rmpfr (version 0.1-7)

Mnumber-class: Class "Mnumber" of "mpfr" and regular numbers and arrays from them

Description

Class "Mnumber" is a class union of "mpfr" and regular numbers and arrays from them. Its purpose is for method dispatch, notably defining a cbind(...) method where ... contains objects of one of the member classes of "Mnumber".

Arguments

See Also

cbind-methods

Examples

Run this code
showClass("Mnumber")

Run the code above in your browser using DataLab