Learn R Programming

Rmpfr (version 0.6-0)

Rmpfr-package: R MPFR - Multiple Precision Floating-Point Reliable

Description

Rmpfr provides S4 classes and methods for arithmetic including transcendental ("special") functions for arbitrary precision floating point numbers, here often called “mpfr - numbers”. To this end, it interfaces to the LGPL'ed MPFR (Multiple Precision Floating-Point Reliable) Library which itself is based on the GMP (GNU Multiple Precision) Library.

Arguments

Details

Package:
Rmpfr
SystemRequirements:
gmp (>= 4.2.3), mpfr (>= 3.0.0)
(C (not R!) libraries; must be installed)
Depends:
methods, gmp (>= 0.5-8), R (>= 2.12.0)
Imports:
gmp, stats, utils
Suggests:
MASS, polynom, sfsmisc (>= 1.0-20), Matrix
SuggestNotes:
MASS, polynom, sfsmisc are only needed for vignette; Matrix only because of its test-tools
URL:
http://rmpfr.r-forge.r-project.org/
License:
GPL (>= 2)

The following (help pages) index does not really mention that we provide many methods for mathematical functions, including gamma, digamma, etc, namely, all of R's (S4) Math group (with the only exception of trigamma), see the list in the examples. Additionally also pnorm, the “error function”, and more, see the list in zeta, and further note the first vignette (below).

Partial index:

mpfr
Create "mpfr" Numbers (Objects)
mpfrArray
Construct "mpfrArray" almost as by array()
mpfr-class
Class "mpfr" of Multiple Precision Floating Point Numbers
mpfrMatrix-class
Classes "mpfrMatrix" and "mpfrArray"
Bernoulli
Bernoulli Numbers in Arbitrary Precision
Bessel_mpfr
Bessel functions of Integer Order in multiple precisions
c.mpfr
MPFR Number Utilities
cbind
"mpfr" ... - Methods for Functions cbind(), rbind()
chooseMpfr
Binomial Coefficients and Pochhammer Symbol aka
Rising Factorial
factorialMpfr
Factorial 'n!' in Arbitrary Precision
formatMpfr
Formatting MPFR (multiprecision) Numbers
getPrec
Rmpfr - Utilities for Precision Setting, Printing, etc
roundMpfr
Rounding to Binary bits, "mpfr-internally"
seqMpfr
"mpfr" Sequence Generation
sumBinomMpfr
(Alternating) Binomial Sums via Rmpfr
zeta
Special Mathematical Functions (MPFR)
integrateR
One-Dimensional Numerical Integration - in pure R
unirootR
One Dimensional Root (Zero) Finding - in pure R
optimizeR
High Precisione One-Dimensional Optimization
hjkMpfr
Hooke-Jeeves Derivative-Free Minimization R (working for MPFR)

Further information is available in the following vignettes:

Rmpfr-pkg
Rmpfr (source, pdf)
log1mexp-note
Acccurately Computing log(1 - exp(.)) -- Assessed by Rmpfr (source, pdf)

References

MPFR (MP Floating-Point Reliable Library), http://mpfr.org/

GMP (GNU Multiple Precision library), http://gmplib.org/

and see the vignettes mentioned above.

See Also

The R package gmp for big integer and rational numbers (bigrational) on which Rmpfr now depends.

Examples

Run this code
## Using  "mpfr" numbers instead of regular numbers...
n1.25 <- mpfr(5, precBits = 256)/4
n1.25

## and then "everything" just works with the desired chosen precision:hig
n1.25 ^ c(1:7, 20, 30) ## fully precise; compare with
print(1.25 ^ 30, digits=19)

exp(n1.25)

## Show all math functions which work with "MPFR" numbers (1 exception: trigamma)
getGroupMembers("Math")

## We provide *many* arithmetic, special function, and other methods:
showMethods(classes = "mpfr")
showMethods(classes = "mpfrArray")

Run the code above in your browser using DataLab