ll{
Package: Rmpfr
SystemRequirements: gmp (>= 4.2.3), mpfr (>= 3.0.0)
(C (not R!) libraries; must be installed)
Depends: methods, gmp (>= 0.5-8), R (>= 2.12.0)
Imports: gmp, stats, utils
Suggests: MASS, polynom, sfsmisc (>= 1.0-20), Matrix
SuggestNotes: MASS, polynom, sfsmisc are only needed for
vignette; Matrix only because of its test-tools
URL: http://rmpfr.r-forge.r-project.org/
License: GPL (>= 2)
}The following (help pages) index does not really mention that we provide many
methods for mathematical functions, including
gamma, digamma, etc, namely, all of R's (S4)
Math group (with the only exception of trigamma),
see the list in the examples.
Additionally also pnorm, the error function,
and more, see the list in zeta, and
further note the first vignette (below).
Partial index:
ll{
mpfr Create "mpfr" Numbers (Objects)
mpfrArray Construct "mpfrArray" almost as by array()
mpfr-class Class "mpfr" of Multiple Precision Floating Point Numbers
mpfrMatrix-class Classes "mpfrMatrix" and "mpfrArray"
Bernoulli Bernoulli Numbers in Arbitrary Precision
Bessel_mpfr Bessel functions of Integer Order in multiple precisions
c.mpfr MPFR Number Utilities
cbind "mpfr" ... - Methods for Functions cbind(), rbind()
chooseMpfr Binomial Coefficients and Pochhammer Symbol aka
Rising Factorial
factorialMpfr Factorial 'n!' in Arbitrary Precision
formatMpfr Formatting MPFR (multiprecision) Numbers
getPrec Rmpfr - Utilities for Precision Setting, Printing, etc
roundMpfr Rounding to Binary bits, "mpfr-internally"
seqMpfr "mpfr" Sequence Generation
sumBinomMpfr (Alternating) Binomial Sums via Rmpfr
zeta Special Mathematical Functions (MPFR)
integrateR One-Dimensional Numerical Integration - in pure R
unirootR One Dimensional Root (Zero) Finding - in pure R
optimizeR High Precisione One-Dimensional Optimization
hjkMpfr Hooke-Jeeves Derivative-Free Minimization R (working for MPFR)
}
Further information is available in the following vignettes:
ll{ Rmpfr-pkg Rmpfr (source, pdf)
log1mexp-note Acccurately Computing log(1 - exp(.)) -- Assessed by Rmpfr (source, pdf)
}